@@ -94,14 +94,16 @@ sub _build_app_commands {
 sub command_args {
     my ($self,$metaclass) = @_;
     
-    $metaclass      ||= $self;
-    my @attributes  = $self->command_usage_attributes_list($metaclass);
-    
-    my ($return,$errors) = $self->command_parse_options(\@attributes);
+    $metaclass ||= $self;
     my $parsed_argv = MooseX::App::ParsedArgv->instance;
     
-    foreach my $option ($parsed_argv->options_available) {
-        push(@{$errors},
+    # Process options
+    my @attributes_option  = $self->command_usage_attributes($metaclass,'option');
+    
+    my ($return,$errors) = $self->command_parse_options(\@attributes_option);
+    
+    while (my $option =$parsed_argv->consume('options') ) {
+        unshift(@{$errors},
             $self->command_message(
                 header          => "Unknown option '".$option->key."'", # LOCALIZE
                 type            => "error",
@@ -109,6 +111,28 @@ sub command_args {
         );
     }
     
+    # Process params
+    my @attributes_parameter  = $self->command_usage_attributes($metaclass,'parameter');
+        
+    foreach my $attribute (@attributes_parameter) {
+        my $value = $parsed_argv->consume('parameters');
+        last
+            unless defined $value;
+
+        my ($parameter_value,$parameter_errors) = $self->command_process_attribute($attribute,$value->key);
+        push(@{$errors},@{$parameter_errors});
+        $return->{$attribute->name} = $parameter_value;
+    }
+    
+    while (my $parameter =$parsed_argv->consume('parameters') ) {
+        unshift(@{$errors},
+            $self->command_message(
+                header          => "Unknown parameter '".$parameter->key."'", # LOCALIZE
+                type            => "error",
+            )
+        );
+    }
+    
     return ($return,$errors);
 }
 
@@ -118,9 +142,11 @@ sub command_proto {
     $metaclass   ||= $self;
     
     my @attributes;
-    foreach my $attribute ($self->command_usage_attributes_list($metaclass)) {
+    foreach my $attribute ($self->command_usage_attributes($metaclass)) {
         next
-            unless $attribute->cmd_proto;
+            unless $attribute->does('AppOption')
+            && $attribute->has_cmd_type
+            && $attribute->cmd_type eq 'proto';
         push(@attributes,$attribute);
     }
     
@@ -150,7 +176,7 @@ sub command_parse_options {
     my $parsed_argv = MooseX::App::ParsedArgv->instance;
     
     # Loop all exact matches
-    foreach my $option ($parsed_argv->options_available()) {
+    foreach my $option ($parsed_argv->available('options')) {
         if (my $attribute = $option_to_attribute{$option->key}) {
             $match->{$attribute->name} = $option->value;
             $option->consume($attribute);
@@ -160,7 +186,7 @@ sub command_parse_options {
     # Process fuzzy matches
     if ($self->app_fuzzy) {
         # Loop all options (sorted by length)
-        foreach my $option (sort { length($b->key) <=> length($a->key) } $parsed_argv->options_available()) {
+        foreach my $option (sort { length($b->key) <=> length($a->key) } $parsed_argv->available('options')) {
 
             # No fuzzy matching for one-letter flags
             my $option_length = length($option->key);
@@ -192,12 +218,13 @@ sub command_parse_options {
                 # One match
                 when(1) {
                     my $attribute = $match_attributes->[0];
-                    $option->consume($attribute);
+                    $option->consume();
                     $match->{$attribute->name} ||= [];
                     push(@{$match->{$attribute->name}},@{$option->value}); 
                 }
                 # Multiple matches
                 default {
+                    $option->consume();
                     push(@errors,
                         $self->command_message(
                             header          => "Ambiguous option '".$option->key."'", # LOCALIZE
@@ -217,64 +244,12 @@ sub command_parse_options {
     
     # Check all attributes
     foreach my $attribute (@{$attributes}) {
-        my $value;
         
         next
             unless exists $match->{$attribute->name};
         
-        # Attribute with type constraint
-        if ($attribute->has_type_constraint) {
-            my $type_constraint = $attribute->type_constraint;
-            
-            if ($type_constraint->is_a_type_of('ArrayRef')) {
-                $value = $match->{$attribute->name};
-            } elsif ($type_constraint->is_a_type_of('HashRef')) {
-                $value = {};
-                foreach my $element (@{$match->{$attribute->name}}) {
-                    if ($element =~ m/^([^=]+)=(.+?)$/) {
-                        $value->{$1} ||= $2;
-                    } else {
-                        push(@errors,
-                            $self->command_message(
-                                header          => "Invalid value for '".$attribute->cmd_name_primary."'", # LOCALIZE
-                                type            => "error",
-                                body            => "Value must be supplied as 'key=value' (not '$element')", # LOCALIZE
-                            )
-                        );
-                    }
-                }
-            } elsif ($type_constraint->is_a_type_of('Bool')) {
-                $value = $attribute->cmd_is_bool; # TODO or 0 if no!
-            } elsif ($type_constraint->is_a_type_of('Int')) {
-                $value = $match->{$attribute->name}[-1];
-            } else {
-                $value = $match->{$attribute->name}[-1];
-            }
-            
-            unless(defined $value) {
-                push(@errors,
-                    $self->command_message(
-                        header          => "Missing value for '".$attribute->cmd_name_primary."'", # LOCALIZE
-                        type            => "error",
-                    )
-                );
-            } else {
-                            
-                my $coercion;
-                if ($attribute->should_coerce
-                    && $type_constraint->has_coercion) {
-                    $coercion = $type_constraint->coercion;
-                    $value = $coercion->coerce($value) // $value;
-                }
-                
-                my $error = $self->command_check_attribute($attribute,$value);
-                push(@errors,$error)
-                    if $error;
-            }
-            
-        } else {
-             $value = $match->{$attribute->name}[-1];
-        }
+        my ($value,$errors) = $self->command_process_attribute($attribute,$match->{$attribute->name});
+        push(@errors,@{$errors});
         
         $return->{$attribute->name} = $value;
     }
@@ -282,6 +257,69 @@ sub command_parse_options {
     return ($return,\@errors);
 }
 
+sub command_process_attribute {
+    my ($self,$attribute,$raw) = @_;
+    
+    $raw = [$raw]
+        unless ref($raw) eq 'ARRAY';
+    
+    my @errors;
+    my $value;
+    # Attribute with type constraint
+    if ($attribute->has_type_constraint) {
+        my $type_constraint = $attribute->type_constraint;
+        
+        if ($type_constraint->is_a_type_of('ArrayRef')) {
+            $value = $raw;
+        } elsif ($type_constraint->is_a_type_of('HashRef')) {
+            $value = {};
+            foreach my $element (@{$raw}) {
+                if ($element =~ m/^([^=]+)=(.+?)$/) {
+                    $value->{$1} ||= $2;
+                } else {
+                    push(@errors,
+                        $self->command_message(
+                            header          => "Invalid value for '".$attribute->cmd_name_primary."'", # LOCALIZE
+                            type            => "error",
+                            body            => "Value must be supplied as 'key=value' (not '$element')", # LOCALIZE
+                        )
+                    );
+                }
+            }
+        } elsif ($type_constraint->is_a_type_of('Bool')) {
+            $value = $attribute->cmd_is_bool; # TODO or 0 if no!
+        } elsif ($type_constraint->is_a_type_of('Int')) {
+            $value = $raw->[-1];
+        } else {
+            $value = $raw->[-1];
+        }
+        
+        unless(defined $value) {
+            push(@errors,
+                $self->command_message(
+                    header          => "Missing value for '".$attribute->cmd_name_primary."'", # LOCALIZE
+                    type            => "error",
+                )
+            );
+        } else {
+                        
+            if ($attribute->should_coerce
+                && $type_constraint->has_coercion) {
+                my $coercion = $type_constraint->coercion;
+                $value = $coercion->coerce($value) // $value;
+            }
+            my $error = $self->command_check_attribute($attribute,$value);
+            push(@errors,$error)
+                if $error;
+        }
+        
+    } else {
+         $value = $raw->[-1];
+    }
+    
+    return ($value,\@errors);
+}
+
 sub command_check_attribute {
     my ($self,$attribute,$value) = @_;
     
@@ -424,17 +462,19 @@ sub command_message {
     return $messageclass->new(@args);
 }
 
-sub command_usage_attributes_list {
-    my ($self,$metaclass) = @_;
+sub command_usage_attributes {
+    my ($self,$metaclass,$types) = @_;
     
     $metaclass ||= $self;
+    $types ||= [qw(option proto)];
     
     my @return;
     # TODO order by insertion order
     foreach my $attribute ($metaclass->get_all_attributes) {
         next
             unless $attribute->does('AppOption')
-            && $attribute->cmd_option;
+            && $attribute->has_cmd_type
+            && $attribute->cmd_type ~~ $types;
         
         push(@return,$attribute);
     }
@@ -442,40 +482,53 @@ sub command_usage_attributes_list {
     return @return;
 }
 
-sub command_usage_attributes_raw {
-    my ($self,$metaclass) = @_;
-    
-    $metaclass ||= $self;
-    
-    my @attributes;
-    foreach my $attribute ($self->command_usage_attributes_list($metaclass)) {
-        
-        my ($attribute_name,$attribute_description) = $attribute->cmd_usage();
-        
-        push(@attributes,[$attribute_name,$attribute_description]);
-    }
-    
-    @attributes = sort { $a->[0] cmp $b->[0] } @attributes;
-    return @attributes;
-}
-
-sub command_usage_attributes {
+sub command_usage_options {
     my ($self,$metaclass,$headline) = @_;
     
     $headline ||= 'options:'; # LOCALIZE
     $metaclass ||= $self;
     
-    my @attributes = $self->command_usage_attributes_raw($metaclass);
+    my @options;
+    foreach my $attribute ($self->command_usage_attributes($metaclass,[qw(option proto)])) {
+        push(@options,[
+            $attribute->cmd_usage_name(),
+            $attribute->cmd_usage_description()
+        ]);
+    }
+    
+    @options = sort { $a->[0] cmp $b->[0] } @options;
     
     return
-        unless scalar @attributes > 1;
+        unless scalar @options > 0;
     
     return $self->command_message(
         header  => $headline,
-        body    => MooseX::App::Utils::format_list(@attributes),
+        body    => MooseX::App::Utils::format_list(@options),
     );
 }
 
+sub command_usage_parameters {
+    my ($self,$metaclass,$headline) = @_;
+    
+    $headline ||= 'parameter:'; # LOCALIZE
+    $metaclass ||= $self;
+    
+    my @parameters;
+    foreach my $attribute ($self->command_usage_attributes($metaclass,'parameter')) {
+        push(@parameters,[
+            $attribute->cmd_usage_name(),
+            $attribute->cmd_usage_description()
+        ]);
+    }
+    
+    return
+        unless scalar @parameters > 0;
+    
+    return $self->command_message(
+        header  => $headline,
+        body    => MooseX::App::Utils::format_list(@parameters),
+    );
+}
 sub command_usage_header {
     my ($self,$command_meta_class) = @_;
     
@@ -489,13 +542,26 @@ sub command_usage_header {
             $usage = MooseX::App::Utils::format_text($command_meta_class->command_usage);
         }
     } else {
-        $command_name = 'command';
+        $command_name = '<command>';
     }
     
-    $usage ||= MooseX::App::Utils::format_text("$caller $command_name [long options...]
+    unless (defined $usage) {
+        # LOCALIZE
+        $usage = "$caller $command_name ";
+        my @parameter= $self->command_usage_attributes($command_meta_class||$self,'parameter');
+        foreach my $attribute (@parameter) {
+            if ($attribute->is_required) {
+                $usage .= "<".$attribute->cmd_usage_name.'> ';
+            } else {
+                $usage .= '['.$attribute->cmd_usage_name.'] ';
+            }
+        }
+        $usage .= "[long options...]
 $caller help
-$caller $command_name --help"); # LOCALIZE
-    
+$caller $command_name --help";
+        $usage = MooseX::App::Utils::format_text($usage);
+    }
+        
     return $self->command_message(
         header  => 'usage:', # LOCALIZE
         body    => $usage,
@@ -546,8 +612,9 @@ sub command_usage_command {
     
     my @usage;
     push(@usage,$self->command_usage_header($command_meta_class));
-    push(@usage,$self->command_usage_description($command_meta_class));
-    push(@usage,$self->command_usage_attributes($command_meta_class));
+    push(@usage,$self->command_usage_description($command_meta_class,)); 
+    push(@usage,$self->command_usage_parameters($command_meta_class,'parameters:')); # LOCALIZE
+    push(@usage,$self->command_usage_options($command_meta_class,'options:')); # LOCALIZE
     
     return @usage;
 }
@@ -574,7 +641,8 @@ sub command_usage_global {
     
     my @usage;
     push (@usage,$self->command_usage_header());
-    push (@usage,$self->command_usage_attributes($self,'global options:')); # LOCALIZE
+    push(@usage,$self->command_usage_parameters($self,'global parameters:')); # LOCALIZE
+    push (@usage,$self->command_usage_options($self,'global options:')); # LOCALIZE
     push (@usage,
         $self->command_message(
             header  => 'available commands:', # LOCALIZE
@@ -668,23 +736,10 @@ Generates a message object (using the class from L<app_messageclass>)
 
 =head2 command_usage_attributes
 
- my $message = $meta->command_usage_attributes($metaclass,$headline);
-
-Returns a message object containing the attribute documentation for a given
-meta class.
-
-=head2 command_usage_attributes_list
-
  my @attributes = $meta->command_usage_attributes($metaclass);
 
 Returns a list of attributes/command options for the given meta class.
 
-=head2 command_usage_attributes_raw
-
- my @attributes = $meta->command_usage_attributes_raw($metaclass);
-
-Returns a list of attribute documentations for a given meta class.
-
 =head2 command_usage_command
 
  my @messages = $meta->command_usage_command($command_metaclass);
@@ -711,12 +766,6 @@ Returns a list of messages containing the documentation for the application.
 
 Returns a message containing the basic usage documentation
 
-=head2 app_commands
-
- my $commands = $meta->app_commands;
-
-Returns a hashref of command name and command class.
-
 =head2 command_find
 
  my @commands = $meta->command_find($user_command_input);
@@ -762,4 +811,22 @@ if a validation error occurs.
 
 Returns a human-readable type constraint description.
 
+=head2 command_process_attributes
+
+ my @attributes = $self->command_process_attributes($metaclass,[qw(option proto)]);
+ my @attributes = $self->command_process_attributes($metaclass,'parameter');
+
+Returns a list of all attributes with the given type
+
+=head2 command_usage_options
+
+ my $usage = $self->command_usage_options($metaclass,$headline);
+
+Returns the options usage as a message object
+
+=head2 command_usage_parameters
+
+ my $usage = $self->command_usage_parameters($metaclass,$headline);
+
+Returns the positional parameters usage as a message object
 =cut
